==> mediawiki-1.10.0.tar.gz: mediawiki-1.10.0/languages/messages/MessagesMi.php <==
<?php
/** Maori (Māori)
 *
 * @addtogroup Language
 */

$messages = array(
# Dates
'sunday'    => 'Rātapu',
'monday'    => 'Rāhina',
'tuesday'   => 'Rātū',
'wednesday' => 'Rāapa',
'thursday'  => 'Rāpare',
'friday'    => 'Rāmere',
'saturday'  => 'Rāhoroi',
'january'   => 'Kohi-tātea',
'february'  => 'Hui-tanguru',
'march'     => 'Poutū-te-rangi',
'april'     => 'Paenga-whāwhā',
'may_long'  => 'Haratua',
'june'      => 'Pipiri',
'july'      => 'Hōngongoi',
'august'    => 'Here-turi-kōkā',
'september' => 'Mahuru',
'october'   => 'Whiringa-ā-nuku',
'november'  => 'Whiringa-ā-rangi',
'december'  => 'Hakihea',

'mainpage' => 'Hau Kāinga',

'portal'         => 'Tomokanga hapori',
'portal-url'     => 'Project:Tomokanga hapori',
'help'           => 'Whakamārama',
'sitesupport'    => 'Koha',
'cancel'         => 'Whakakore',
'qbspecialpages' => 'Whārangi motuhake',
'mytalk'         => 'Karere mōku',
'navigation'     => 'Huarahi',

'currentevents'     => 'Kōrero',
'currentevents-url' => 'Project:Kōrero',

'search'           => 'Rapua',
'go'               => 'Haere',
'history'          => 'Kōrero Nehe',
'history_short'    => 'Tuhinga/kaituhi',
'printableversion' => 'Tāia',
'permalink'        => 'Hononga toitū',
'edit'             => 'Whakatika',
'delete'           => 'tangohia',
'protect'          => 'Whakangungua',
'talk'             => 'Kōrerorero',
'toolbox'          => 'Pouaka utauta',

'toc'     => 'Rārangi kōrero',
'showtoc' => 'whakakite',
'hidetoc' => 'hunaia',

# Short words for each namespace, by default used in the 'article' tab in monobook
'nstab-main'     => 'tuhi pānui',
'nstab-template' => 'papa tauira',
'nstab-help'     => 'Āwhina',
'nstab-category' => 'Wāhanga',

# Login and logout pages
'userlogout' => 'Whakarere',

# Edit pages
'savearticle' => 'Tiaki',
'showdiff'    => 'Tiro rerekētanga',

# Preferences page
'preferences' => 'Kōwhiringa',

# Recent changes
'recentchanges' => 'Rerekētanga hōu',
'hide'          => 'Hunaia',
'show'          => 'Whakaaturia',

# Upload
'upload' => 'Tuku atu',

# Miscellaneous special pages
'allpages'            => 'Ngā whārangi katoa',
'randompage'          => 'Tipihaere',
'specialpages'        => 'Whārangi motuhake',
'recentchangeslinked' => 'Rerekētanga pū tahi',
'move'                => 'Nekehia',

# Special:Allpages
'allpagessubmit' => 'Haere',

# Watchlist
'watchlist' => 'Rārangi mātaki',
'mywatchlist' => 'Rārangi mātaki',
'watch'     => 'Mātaki',
'unwatch'   => 'kāti te mātaki',

# Contributions
'contributions' => 'Ngā mahi a tēnei mema',
'mycontris'     => 'āku mahi',

# What links here
'whatlinkshere' => 'Ngā hononga mai',

# Namespace 8 related
'allmessages' => 'Pānui pūnaha',

);

?>

==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesMi.php <==
<?php
/** Maori (Māori)
 *
 * @ingroup Language
 * @file
 *
 * @author Kiharoa
 */

$messages = array(
# Dates
'sunday'    => 'Rātapu',
'monday'    => 'Rāhina',
'tuesday'   => 'Rātū',
'wednesday' => 'Rāapa',
'thursday'  => 'Rāpare',
'friday'    => 'Rāmere',
'saturday'  => 'Rāhoroi',
'january'   => 'Kohi-tātea',
'february'  => 'Hui-tanguru',
'march'     => 'Poutū-te-rangi',
'april'     => 'Paenga-whāwhā',
'may_long'  => 'Haratua',
'june'      => 'Pipiri',
'july'      => 'Hōngongoi',
'august'    => 'Here-turi-kōkā',
'september' => 'Mahuru',
'october'   => 'Whiringa-ā-nuku',
'november'  => 'Whiringa-ā-rangi',
'december'  => 'Hakihea',

'cancel'         => 'Whakakore',
'qbspecialpages' => 'Whārangi motuhake',
'mytalk'         => 'Karere mōku',
'navigation'     => 'Huarahi',

'help'             => 'Whakamārama',
'search'           => 'Rapua',
'go'               => 'Haere',
'history'          => 'Kōrero Nehe',
'history_short'    => 'Tuhinga/kaituhi',
'printableversion' => 'Tāia',
'permalink'        => 'Hononga toitū',
'edit'             => 'Whakatika',
'delete'           => 'tangohia',
'protect'          => 'Whakangungua',
'talk'             => 'Kōrerorero',
'toolbox'          => 'Pouaka utauta',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Mo {{SITENAME}}',
'currentevents'        => 'Kōrero',
'currentevents-url'    => 'Project:Kōrero',
'mainpage'             => 'Hau Kāinga',
'mainpage-description' => 'Hau Kāinga',
'portal'               => 'Tomokanga hapori',
'portal-url'           => 'Project:Tomokanga hapori',
'privacy'              => 'Tikanga tūmataiti',
'privacypage'          => 'Project:Tikanga tūmataiti',

'toc'     => 'Rārangi kōrero',
'showtoc' => 'whakakite',
'hidetoc' => 'hunaia',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'tuhi pānui',
'nstab-template' => 'papa tauira',
'nstab-help'     => 'Āwhina',
'nstab-category' => 'Wāhanga',

# Login and logout pages
'userlogout' => 'Whakarere',

# Edit pages
'savearticle' => 'Tiaki',
'showdiff'    => 'Tiro rerekētanga',

# Preferences page
'preferences' => 'Kōwhiringa',

# Recent changes
'recentchanges' => 'Rerekētanga hōu',
'hide'          => 'Hunaia',
'show'          => 'Whakaaturia',

# Recent changes linked
'recentchangeslinked' => 'Rerekētanga pū tahi',

# Upload
'upload' => 'Tuku atu',

# Random page
'randompage' => 'Tipihaere',

# Miscellaneous special pages
'move' => 'Nekehia',

# Special:AllPages
'allpages'       => 'Ngā whārangi katoa',
'allpagessubmit' => 'Haere',

# Watchlist
'watchlist'   => 'Rārangi mātaki',
'mywatchlist' => 'Rārangi mātaki',
'watch'       => 'Mātaki',
'unwatch'     => 'kāti te mātaki',

# Contributions
'contributions' => 'Ngā mahi a tēnei mema',
'mycontris'     => 'āku mahi',

# What links here
'whatlinkshere' => 'Ngā hononga mai',

# Namespace 8 related
'allmessages' => 'Pānui pūnaha',

# Special:SpecialPages
'specialpages' => 'Whārangi motuhake',

);
